summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--cui/inc/tipoftheday.hrc8
-rw-r--r--cui/inc/treeopt.hrc4
-rw-r--r--cui/source/inc/treeopt.hxx2
-rw-r--r--cui/source/tabpages/numfmt.cxx2
-rw-r--r--cui/uiconfig/ui/numberingformatpage.ui2
-rw-r--r--cui/uiconfig/ui/opthtmlpage.ui2
-rw-r--r--editeng/source/editeng/editview.cxx8
-rw-r--r--filter/source/msfilter/svdfppt.cxx2
-rw-r--r--filter/uiconfig/ui/pdfviewpage.ui2
-rw-r--r--include/jvmfwk/framework.hxx2
-rw-r--r--include/svl/zforlist.hxx2
-rw-r--r--officecfg/registry/schema/org/openoffice/Office/Linguistic.xcs2
-rw-r--r--officecfg/registry/schema/org/openoffice/Setup.xcs6
-rw-r--r--readlicense_oo/docs/readme.xrm2
-rw-r--r--reportbuilder/Package_templates.mk2
-rw-r--r--sc/source/filter/excel/xestyle.cxx2
-rw-r--r--scaddins/source/analysis/analysishelper.hxx4
-rw-r--r--sd/source/ui/docshell/docshel3.cxx2
-rw-r--r--setup_native/source/mac/macinstall.ulf2
-rw-r--r--svtools/uiconfig/ui/restartdialog.ui2
-rw-r--r--svx/inc/svxerr.hrc2
-rw-r--r--sw/qa/uitest/findReplace/tdf118208.py13
-rw-r--r--sw/source/core/access/AccessibilityIssue.cxx2
-rw-r--r--sw/source/filter/ww8/wrtw8sty.cxx2
-rw-r--r--sw/source/uibase/shells/langhelper.cxx2
-rw-r--r--sw/source/uibase/shells/textsh1.cxx2
-rw-r--r--sw/uiconfig/swriter/ui/textgridpage.ui2
27 files changed, 43 insertions, 42 deletions
diff --git a/cui/inc/tipoftheday.hrc b/cui/inc/tipoftheday.hrc
index 7f1dca4441d9..ed4b7b72eb3d 100644
--- a/cui/inc/tipoftheday.hrc
+++ b/cui/inc/tipoftheday.hrc
@@ -135,7 +135,7 @@ const std::tuple<TranslateId, OUString, OUString, tipModule> TIPOFTHEDAY_STRINGA
{ NC_("RID_CUI_TIPOFTHEDAY", "In %PRODUCTNAME Impress, use Insert ▸ Media ▸ Photo Album to create a slideshow from a series of pictures with the “Photo Album” feature."), "", "", simpress},
{ NC_("RID_CUI_TIPOFTHEDAY", "You can show formulas instead of results with View ▸ Show Formula (or Tools ▸ Options ▸ %PRODUCTNAME Calc ▸ View ▸ Display ▸ Formulas)."), "", "", scalc},
{ NC_("RID_CUI_TIPOFTHEDAY", "%PRODUCTNAME is developed by a friendly community, made up of hundreds of contributors around the world. Join us with your skills beyond coding."), "https://www.libreoffice.org/community/get-involved/", "", soffice},
- { NC_("RID_CUI_TIPOFTHEDAY", "Left-handed? Enable Tools ▸ Options ▸ Language Settings ▸ Languages ▸ Asian and check Tools ▸ Options ▸ %PRODUCTNAME Writer ▸ View ▸ Ruler ▸ Right-aligned, which displays the scrollbar to the left."), "", "", swriter},
+ { NC_("RID_CUI_TIPOFTHEDAY", "Left-handed? Enable Tools ▸ Options ▸ Languages and Locales ▸ General ▸ Asian and check Tools ▸ Options ▸ %PRODUCTNAME Writer ▸ View ▸ Ruler ▸ Right-aligned, which displays the scrollbar to the left."), "", "", swriter},
{ NC_("RID_CUI_TIPOFTHEDAY", "Want headings to always begin a page? Edit the paragraph style applied to the headings. Check “Insert” on the “Text Flow” tab, with Type “Page” and Position “Before”."), "cui/ui/textflowpage/checkInsert", "", swriter},
{ NC_("RID_CUI_TIPOFTHEDAY", "Date/time value is just a number of days since a chosen day zero; in the number, integer part represents date, and fractional part is time (elapsed part of a day), with 0.5 representing noon."), "", "", scalc},
{ NC_("RID_CUI_TIPOFTHEDAY", "Shift+%MOD1+Del deletes from cursor to the end of the current sentence."), "", "", swriter},
@@ -185,7 +185,7 @@ const std::tuple<TranslateId, OUString, OUString, tipModule> TIPOFTHEDAY_STRINGA
{ NC_("RID_CUI_TIPOFTHEDAY", "Your donations support our worldwide community."), "https://www.libreoffice.org/donate/", "", soffice},
{ NC_("RID_CUI_TIPOFTHEDAY", "You want to add x months to a date? Use =EDATE(date;months)."), "https://help.libreoffice.org/%PRODUCTVERSION/%LANGUAGENAME/text/scalc/01/func_edate.html", "", scalc}, //local help missing
{ NC_("RID_CUI_TIPOFTHEDAY", "To select a contiguous range of cells containing data and bounded by empty row and columns use %MOD1+* (numeric key pad)."), "", "", scalc},
- { NC_("RID_CUI_TIPOFTHEDAY", "Your date acceptance pattern is inappropriate? Use Tools ▸ Options ▸ Language Settings ▸ Languages ▸ Date acceptance patterns to tweak the pattern."), "", "", soffice},
+ { NC_("RID_CUI_TIPOFTHEDAY", "Your date acceptance pattern is inappropriate? Use Tools ▸ Options ▸ Languages and Locales ▸ General ▸ Date acceptance patterns to tweak the pattern."), "", "", soffice},
{ NC_("RID_CUI_TIPOFTHEDAY", "Want to export formulas to CSV? File ▸ Save As ▸ Type:Text CSV, check “Edit filter settings”, and check “Save cell formulas” in the next dialog."), "", "", scalc},
{ NC_("RID_CUI_TIPOFTHEDAY", "The presenter console is a great feature when working with %PRODUCTNAME Impress. Have you checked it out?"), "https://help.libreoffice.org/%PRODUCTVERSION/%LANGUAGENAME/text/simpress/guide/presenter_console.html", "", simpress}, //local help missing
{ NC_("RID_CUI_TIPOFTHEDAY", "To delete multiple comments, select cells with comments and use Sheet ▸ Cell Comments ▸ Delete Comment."), "", "", scalc},
@@ -216,7 +216,7 @@ const std::tuple<TranslateId, OUString, OUString, tipModule> TIPOFTHEDAY_STRINGA
{ NC_("RID_CUI_TIPOFTHEDAY", "Rename your slides in Impress to help you define “Go to page” interactions and to have a summary more explicit than Slide1, Slide2…"), "", "", simpress},
{ NC_("RID_CUI_TIPOFTHEDAY", "Want to display text before a heading number? Open the Numbering tab of the “Heading Numbering” dialog and enter the desired text in “Before”. For example, type “Chapter ” to display “Chapter 1”."), "modules/swriter/ui/outlinenumberingpage/prefix", "", swriter},
{ NC_("RID_CUI_TIPOFTHEDAY", "Transpose a Writer table? Copy and paste in Calc, transpose with copy/paste special then copy/paste special ▸ Formatted text in Writer."), "", "", swriter},
- { NC_("RID_CUI_TIPOFTHEDAY", "To get the “Vertical Text” tool in the Drawing toolbar, check Tools ▸ Options ▸ Language Settings ▸ Languages ▸ Default languages for Documents ▸ Asian (and make the button visible with right-click and then Visible Buttons ▸ Vertical Text)."), "", "", soffice},
+ { NC_("RID_CUI_TIPOFTHEDAY", "To get the “Vertical Text” tool in the Drawing toolbar, check Tools ▸ Options ▸ Languages and Locales ▸ General ▸ Default languages for Documents ▸ Asian (and make the button visible with right-click and then Visible Buttons ▸ Vertical Text)."), "", "", soffice},
{ NC_("RID_CUI_TIPOFTHEDAY", "To quickly zoom in on range selection, right click on the zoom part of the status bar and choose Optimal."), "", "", scalc},
{ NC_("RID_CUI_TIPOFTHEDAY", "You can sign existing PDF files and also verify those signatures."), "https://help.libreoffice.org/%PRODUCTVERSION/%LANGUAGENAME/text/shared/guide/digital_signatures.html", "", soffice}, //local help missing
{ NC_("RID_CUI_TIPOFTHEDAY", "Often create one document from another? Consider using a template."), "", "", swriter},
@@ -270,7 +270,7 @@ const std::tuple<TranslateId, OUString, OUString, tipModule> TIPOFTHEDAY_STRINGA
{ NC_("RID_CUI_TIPOFTHEDAY", "Drag & drop cells from Calc into the normal view of a slide creates a table; into the outline view, each cell creates a line in the outline."), "", "", scalc},
{ NC_("RID_CUI_TIPOFTHEDAY", "%PRODUCTNAME helps you not to enter two or more spaces in Writer. Check Tools ▸ AutoCorrect ▸ AutoCorrect Options ▸ Options ▸ Ignore double spaces."), "", "", swriter},
{ NC_("RID_CUI_TIPOFTHEDAY", "Want the cursor to go into the cell to the right, after entering a value in Calc? Use the Tab key instead of Enter."), "", "", scalc},
- { NC_("RID_CUI_TIPOFTHEDAY", "To display the scrollbar to the left, enable Tools ▸ Options ▸ Language Settings ▸ Languages ▸ Complex text and right click a sheet in Sheet tabs above Status bar ▸ Right-To-Left."), "", "", scalc},
+ { NC_("RID_CUI_TIPOFTHEDAY", "To display the scrollbar to the left, enable Tools ▸ Options ▸ Languages and Locales ▸ General ▸ Complex text and right click a sheet in Sheet tabs above Status bar ▸ Right-To-Left."), "", "", scalc},
{ NC_("RID_CUI_TIPOFTHEDAY", "Drag a formatted object to the Styles and Formatting window. A dialog box opens, just enter the name of the new style."), "", "", swriter},
{ NC_("RID_CUI_TIPOFTHEDAY", "New versions of %PRODUCTNAME provide new features, bug fixes, and security patches. Keep your software updated!"), "SFX2_HID_DLG_CHECKFORONLINEUPDATE", "", soffice},
{ NC_("RID_CUI_TIPOFTHEDAY", "Developing new XSLT and XML filters?"), "https://fridrich.blogspot.com/2013/08/extending-swiss-army-knife-overview.html", "", soffice},
diff --git a/cui/inc/treeopt.hrc b/cui/inc/treeopt.hrc
index 27b7998c8c2d..602eb5b6b47a 100644
--- a/cui/inc/treeopt.hrc
+++ b/cui/inc/treeopt.hrc
@@ -50,8 +50,8 @@ const std::pair<TranslateId, sal_uInt16> SID_GENERAL_OPTIONS_RES[] =
const std::pair<TranslateId, sal_uInt16> SID_LANGUAGE_OPTIONS_RES[] =
{
- { NC_("SID_LANGUAGE_OPTIONS_RES", "Language Settings"), 0 },
- { NC_("SID_LANGUAGE_OPTIONS_RES", "Languages"), OFA_TP_LANGUAGES },
+ { NC_("SID_LANGUAGE_OPTIONS_RES", "Languages and Locales"), 0 },
+ { NC_("SID_LANGUAGE_OPTIONS_RES", "General"), OFA_TP_LANGUAGES },
{ NC_("SID_LANGUAGE_OPTIONS_RES", "Writing Aids"), RID_SFXPAGE_LINGU },
{ NC_("SID_LANGUAGE_OPTIONS_RES", "Searching in Japanese"), RID_SVXPAGE_JSEARCH_OPTIONS },
{ NC_("SID_LANGUAGE_OPTIONS_RES", "Asian Layout"), RID_SVXPAGE_ASIAN_LAYOUT },
diff --git a/cui/source/inc/treeopt.hxx b/cui/source/inc/treeopt.hxx
index b3f54dc0c533..307c70f9edd5 100644
--- a/cui/source/inc/treeopt.hxx
+++ b/cui/source/inc/treeopt.hxx
@@ -232,7 +232,7 @@ public:
// default value initializes all dialogs
void initializeFirstNDialog(sal_Int16 nNumberOfNode = -1);
- // helper functions to call the language settings TabPage from the SpellDialog
+ // helper functions to call the Languages and Locales TabPage from the SpellDialog
static void ApplyLanguageOptions(const SfxItemSet& rSet);
static OUString getCurrentFactory_Impl( const css::uno::Reference< css::frame::XFrame >& _xFrame );
diff --git a/cui/source/tabpages/numfmt.cxx b/cui/source/tabpages/numfmt.cxx
index 9bdcb0e6b0a5..21972673cc56 100644
--- a/cui/source/tabpages/numfmt.cxx
+++ b/cui/source/tabpages/numfmt.cxx
@@ -641,7 +641,7 @@ void SvxNumberFormatTabPage::EnableBySourceFormat_Impl()
#*------------------------------------------------------------------------
#*
#* Class: SvxNumberFormatTabPage
-#* Function: Hides the language settings:
+#* Function: Hides the Languages and Locales:
#* Input: sal_Bool nFlag
#* Output: ---
#*
diff --git a/cui/uiconfig/ui/numberingformatpage.ui b/cui/uiconfig/ui/numberingformatpage.ui
index 2954e7f4bab5..b6147e0a3717 100644
--- a/cui/uiconfig/ui/numberingformatpage.ui
+++ b/cui/uiconfig/ui/numberingformatpage.ui
@@ -396,7 +396,7 @@
<property name="draw_indicator">True</property>
<child internal-child="accessible">
<object class="AtkObject" id="thousands-atkobject">
- <property name="AtkObject::accessible-description" translatable="yes" context="numberingformatpage|extended_tip|thousands">Inserts a separator between thousands. The type of separator that is used depends on your language settings.</property>
+ <property name="AtkObject::accessible-description" translatable="yes" context="numberingformatpage|extended_tip|thousands">Inserts a separator between thousands. The type of separator that is used depends on your Languages and Locales settings.</property>
</object>
</child>
</object>
diff --git a/cui/uiconfig/ui/opthtmlpage.ui b/cui/uiconfig/ui/opthtmlpage.ui
index 8c0f88436570..5cfc7fd11875 100644
--- a/cui/uiconfig/ui/opthtmlpage.ui
+++ b/cui/uiconfig/ui/opthtmlpage.ui
@@ -480,7 +480,7 @@
<property name="draw-indicator">True</property>
<child internal-child="accessible">
<object class="AtkObject" id="numbersenglishus-atkobject">
- <property name="AtkObject::accessible-description" translatable="yes" context="extended_tip|numbersenglishus">If not checked, numbers will be interpreted according to the setting in Language Settings - Language of - Locale setting in the Options dialog box. If checked, numbers will be interpreted as 'English (USA)' locale.</property>
+ <property name="AtkObject::accessible-description" translatable="yes" context="extended_tip|numbersenglishus">If not checked, numbers will be interpreted according to the setting in Languages and Locales - General - Locale setting in the Options dialog box. If checked, numbers will be interpreted as 'English (USA)' locale.</property>
</object>
</child>
</object>
diff --git a/editeng/source/editeng/editview.cxx b/editeng/source/editeng/editview.cxx
index 81cc8bf1aa56..adf135b8e7f6 100644
--- a/editeng/source/editeng/editview.cxx
+++ b/editeng/source/editeng/editview.cxx
@@ -87,7 +87,7 @@ LanguageType EditView::CheckLanguage(
// If the result from language guessing does not provide a 'Country'
// part, try to get it by looking up the locale setting of the office,
- // "Tools/Options - Language Settings - Languages: Locale setting", if
+ // "Tools/Options - Languages and Locales - General: Locale setting", if
// the language matches.
if ( aGuessTag.getCountry().isEmpty() )
{
@@ -114,12 +114,12 @@ LanguageType EditView::CheckLanguage(
const AllSettings& rSettings = Application::GetSettings();
SvtLinguOptions aLinguOpt;
SvtLinguConfig().GetOptions( aLinguOpt );
- // The default document language from "Tools/Options - Language Settings - Languages: Western"
+ // The default document language from "Tools/Options - Languages and Locales - General: Western"
aLangList[0] = MsLangId::resolveSystemLanguageByScriptType( aLinguOpt.nDefaultLanguage,
css::i18n::ScriptType::LATIN);
- // The one from "Tools/Options - Language Settings - Languages: User interface"
+ // The one from "Tools/Options - Languages and Locales - General: User interface"
aLangList[1] = rSettings.GetUILanguageTag().getLanguageType();
- // The one from "Tools/Options - Language Settings - Languages: Locale setting"
+ // The one from "Tools/Options - Languages and Locales - General: Locale setting"
aLangList[2] = rSettings.GetLanguageTag().getLanguageType();
// en-US
aLangList[3] = LANGUAGE_ENGLISH_US;
diff --git a/filter/source/msfilter/svdfppt.cxx b/filter/source/msfilter/svdfppt.cxx
index 0ef068f94e0c..a9b73ddf9b65 100644
--- a/filter/source/msfilter/svdfppt.cxx
+++ b/filter/source/msfilter/svdfppt.cxx
@@ -6626,7 +6626,7 @@ PPTTextObj::PPTTextObj( SvStream& rIn, SdrPowerPointImport& rSdrPowerPointImport
if ( !nParagraphs )
return;
- // the language settings will be merged into the list of PPTCharPropSet
+ // the languages and locales will be merged into the list of PPTCharPropSet
DffRecordHeader aTextSpecInfoHd;
PPTTextSpecInfoAtomInterpreter aTextSpecInfoAtomInterpreter;
if ( SvxMSDffManager::SeekToRec( rIn, PPT_PST_TextSpecInfoAtom,
diff --git a/filter/uiconfig/ui/pdfviewpage.ui b/filter/uiconfig/ui/pdfviewpage.ui
index e8f568b5b423..2e70dbd2ceca 100644
--- a/filter/uiconfig/ui/pdfviewpage.ui
+++ b/filter/uiconfig/ui/pdfviewpage.ui
@@ -447,7 +447,7 @@
<property name="draw-indicator">True</property>
<child internal-child="accessible">
<object class="AtkObject" id="firstonleft-atkobject">
- <property name="AtkObject::accessible-description" translatable="yes" context="pdfviewpage|extended_tip|firstonleft">Select to generate a PDF file that shows pages side by side in a continuous column. For more than two pages, the first page is displayed on the left. You must enable support for complex text layout on Language settings - Languages in the Options dialog box.</property>
+ <property name="AtkObject::accessible-description" translatable="yes" context="pdfviewpage|extended_tip|firstonleft">Select to generate a PDF file that shows pages side by side in a continuous column. For more than two pages, the first page is displayed on the left. You must enable support for complex text layout on Languages and Locales - General in the Options dialog box.</property>
</object>
</child>
</object>
diff --git a/include/jvmfwk/framework.hxx b/include/jvmfwk/framework.hxx
index d3cf01791e6b..4eaacfce975d 100644
--- a/include/jvmfwk/framework.hxx
+++ b/include/jvmfwk/framework.hxx
@@ -401,7 +401,7 @@ JVMFWK_DLLPUBLIC javaFrameworkError jfw_getJavaInfoByPath(OUString const& pPath,
The <code>arOptions</code>
argument contains start arguments which are passed in JavaVMOption structures
to the VM during its creation. These
- could be things, such as language settings, proxy settings or any other
+ could be things, such as language and locale settings, proxy settings or any other
properties which shall be obtainable by
<code>java.lang.System.getProperties</code>. One can also pass options which
have a certain meaning to the runtime behaviour such as -ea or -X... However,
diff --git a/include/svl/zforlist.hxx b/include/svl/zforlist.hxx
index 4159ce0fbebc..f9edfdf783ef 100644
--- a/include/svl/zforlist.hxx
+++ b/include/svl/zforlist.hxx
@@ -353,7 +353,7 @@ public:
std::u16string_view rSymStr, sal_uInt16 nNegaFormat);
/** Representation of a currency (symbol position and
- negative sign) in other language settings */
+ negative sign) in other locales */
static sal_uInt16 GetEffectivePositiveFormat( sal_uInt16 nIntlFormat,
sal_uInt16 nCurrFormat, bool bBank );
static sal_uInt16 GetEffectiveNegativeFormat( sal_uInt16 nIntlFormat,
diff --git a/officecfg/registry/schema/org/openoffice/Office/Linguistic.xcs b/officecfg/registry/schema/org/openoffice/Office/Linguistic.xcs
index 501a2369dc1c..8fcb6a3ccd62 100644
--- a/officecfg/registry/schema/org/openoffice/Office/Linguistic.xcs
+++ b/officecfg/registry/schema/org/openoffice/Office/Linguistic.xcs
@@ -137,7 +137,7 @@
configurations.</desc>
</info>
<prop oor:name="UILocale" oor:type="xs:string" oor:nillable="false">
- <!-- UIHints: Tools - Options - General - Language Settings - Languages
+ <!-- UIHints: Tools - Options - General - Languages and Locales - General
-->
<info>
<desc>Specifies the UI language. An empty string means: use the
diff --git a/officecfg/registry/schema/org/openoffice/Setup.xcs b/officecfg/registry/schema/org/openoffice/Setup.xcs
index a3aac9276ecd..82e23f0d8d9f 100644
--- a/officecfg/registry/schema/org/openoffice/Setup.xcs
+++ b/officecfg/registry/schema/org/openoffice/Setup.xcs
@@ -373,7 +373,7 @@
<value/>
</prop>
<prop oor:name="ooSetupSystemLocale" oor:type="xs:string" oor:nillable="false">
- <!-- UIHints: Tools - Options - Language Settings - Languages - Language
+ <!-- UIHints: Tools - Options - Languages and Locales - General - Language
of - Locale setting -->
<info>
<desc>Indicates the locale setting defined by the user. By default,
@@ -384,7 +384,7 @@
was intended -->
</prop>
<prop oor:name="ooSetupCurrency" oor:type="xs:string" oor:nillable="false">
- <!-- UIHints: Tools - Options - Language Settings - Languages - Language
+ <!-- UIHints: Tools - Options - Languages and Locales - General - Language
of - Default currency -->
<info>
<desc>Indicates the currency settings defined by the user. By default,
@@ -415,7 +415,7 @@
<value>false</value>
</prop>
<prop oor:name="DateAcceptancePatterns" oor:type="xs:string" oor:nillable="true">
- <!-- UIHints: Tools - Options - Language Settings - Languages - Language
+ <!-- UIHints: Tools - Options - Languages and Locales - General - Language
of - Date acceptance patterns -->
<info>
<desc>Indicates the date acceptance patterns defined by the user. By
diff --git a/readlicense_oo/docs/readme.xrm b/readlicense_oo/docs/readme.xrm
index d49f4fea2e03..04d8b4c7f627 100644
--- a/readlicense_oo/docs/readme.xrm
+++ b/readlicense_oo/docs/readme.xrm
@@ -115,7 +115,7 @@
<p id="linuxlangpack7" xml:lang="en-US">For Fedora-based systems: su -c 'dnf install *.rpm'</p>
<p id="linuxlangpack8" xml:lang="en-US">For Mandriva-based systems: sudo urpmi *.rpm</p>
<p id="linuxlangpack9" xml:lang="en-US">For other RPM-using systems (openSUSE, etc.): rpm -Uvh *.rpm</p>
- <p id="linuxlangpackA" xml:lang="en-US">Now start one of the ${PRODUCTNAME} applications - Writer, for instance. Go to the Tools menu and choose Options. In the Options dialog box, click on "Language Settings" and then click on "Languages". Dropdown the "User interface" list and select the language you just installed. If you want, do the same thing for the "Locale setting", the "Default currency", and the "Default languages for documents".</p>
+ <p id="linuxlangpackA" xml:lang="en-US">Now start one of the ${PRODUCTNAME} applications - Writer, for instance. Go to the Tools menu and choose Options. In the Options dialog box, click on "Languages and Locales" and then click on "General". Dropdown the "User interface" list and select the language you just installed. If you want, do the same thing for the "Locale setting", the "Default currency", and the "Default languages for documents".</p>
<p id="linuxlangpackB" xml:lang="en-US">After adjusting those settings, click on OK. The dialog box will close, and you will see an information message telling you that your changes will only be activated after you exit ${PRODUCTNAME} and start it again (remember to also exit the QuickStarter if it is started).</p>
<p id="linuxlangpackC" xml:lang="en-US">The next time you start ${PRODUCTNAME}, it will start in the language you just installed.</p>
</div>
diff --git a/reportbuilder/Package_templates.mk b/reportbuilder/Package_templates.mk
index 570c1f880514..4585d8afcbc7 100644
--- a/reportbuilder/Package_templates.mk
+++ b/reportbuilder/Package_templates.mk
@@ -8,7 +8,7 @@
#
# There is currently only a single, en-US, template that needs to be included in
-# any installation set regardless of language settings, so keep this as a
+# any installation set regardless of languages and locales, so keep this as a
# Package instead of an AllLangPackage (whose content would need to go into a
# language pack in scp2) for now.
diff --git a/sc/source/filter/excel/xestyle.cxx b/sc/source/filter/excel/xestyle.cxx
index 2230987ce8b0..678327bd1a58 100644
--- a/sc/source/filter/excel/xestyle.cxx
+++ b/sc/source/filter/excel/xestyle.cxx
@@ -837,7 +837,7 @@ sal_Int16 XclExpFontHelper::GetFirstUsedScript( const XclExpRoot& rRoot, const S
/* #i17050# #i107170# We need to determine which font items are set in the
item set, and which script type we should prefer according to the
- current language settings. */
+ current languages and locales. */
static const WhichAndScript WAS_LATIN( ATTR_FONT, css::i18n::ScriptType::LATIN );
static const WhichAndScript WAS_ASIAN( ATTR_CJK_FONT, css::i18n::ScriptType::ASIAN );
diff --git a/scaddins/source/analysis/analysishelper.hxx b/scaddins/source/analysis/analysishelper.hxx
index 835593518a98..0fdae29ccd66 100644
--- a/scaddins/source/analysis/analysishelper.hxx
+++ b/scaddins/source/analysis/analysishelper.hxx
@@ -820,7 +820,7 @@ inline void ScaDate::addYears( sal_Int32 nYearCount )
}
-/// Helper class for Any->double conversion, using current language settings
+/// Helper class for Any->double conversion, using the current locale
class ScaAnyConverter
{
private:
@@ -841,7 +841,7 @@ public:
const css::uno::Reference< css::uno::XComponentContext >& xContext );
~ScaAnyConverter();
- /// Initializing with current language settings
+ /// Initializing with the current locale
///
/// @throws css::uno::RuntimeException
void init(
diff --git a/sd/source/ui/docshell/docshel3.cxx b/sd/source/ui/docshell/docshel3.cxx
index abc9dc9fb67e..f310ddcfc676 100644
--- a/sd/source/ui/docshell/docshel3.cxx
+++ b/sd/source/ui/docshell/docshel3.cxx
@@ -279,7 +279,7 @@ void DrawDocShell::Execute( SfxRequest& rReq )
if (aNewLangTxt == "*" )
{
- // open the dialog "Tools/Options/Language Settings - Language"
+ // open the dialog "Tools/Options/Languages and Locales - General"
if (mpViewShell)
{
SfxAbstractDialogFactory* pFact = SfxAbstractDialogFactory::Create();
diff --git a/setup_native/source/mac/macinstall.ulf b/setup_native/source/mac/macinstall.ulf
index d0a937278577..e26b9f9013ef 100644
--- a/setup_native/source/mac/macinstall.ulf
+++ b/setup_native/source/mac/macinstall.ulf
@@ -62,7 +62,7 @@ en-US = "Installation failed."
en-US = "Installation of [PRODUCTNAME] language pack completed."
[InstallCompleteText2]
-en-US = "Call '[PRODUCTNAME] - Preferences - Language Settings - Languages' to change the user interface language."
+en-US = "Call '[PRODUCTNAME] - Preferences - Languages and Locales - General' to change the user interface language."
[InstallCompleteTextPatch]
en-US = "Installation of [FULLPRODUCTNAME] completed"
diff --git a/svtools/uiconfig/ui/restartdialog.ui b/svtools/uiconfig/ui/restartdialog.ui
index d6076a3fe01b..05d83c00037e 100644
--- a/svtools/uiconfig/ui/restartdialog.ui
+++ b/svtools/uiconfig/ui/restartdialog.ui
@@ -157,7 +157,7 @@
<object class="GtkLabel" id="reason_language_change">
<property name="can-focus">False</property>
<property name="no-show-all">True</property>
- <property name="label" translatable="yes" context="restartdialog|reason_language_change">For the updated language settings to take effect, %PRODUCTNAME must be restarted.</property>
+ <property name="label" translatable="yes" context="restartdialog|reason_language_change">For the updated UI language setting to take effect, %PRODUCTNAME must be restarted.</property>
<property name="wrap">True</property>
<property name="max-width-chars">50</property>
<property name="xalign">0</property>
diff --git a/svx/inc/svxerr.hrc b/svx/inc/svxerr.hrc
index eab36d8c6570..d968a5b7479a 100644
--- a/svx/inc/svxerr.hrc
+++ b/svx/inc/svxerr.hrc
@@ -46,7 +46,7 @@ const ErrMsgCode RID_SVXERRCTX[] =
// Error-Code ------------------------------------------------------------
const ErrMsgCode RID_SVXERRCODE[] =
{
- { NC_("RID_SVXERRCODE", "$(ARG1) is not supported by the spellcheck function or is not presently active.\nPlease check your installation and, if necessary, install the required language module\nor activate it under 'Tools - Options - Language Settings - Writing Aids'."),
+ { NC_("RID_SVXERRCODE", "$(ARG1) is not supported by the spellcheck function or is not presently active.\nPlease check your installation and, if necessary, install the required language module\nor activate it under 'Tools - Options - Languages and Locales - Writing Aids'."),
ERRCODE_SVX_LINGU_LANGUAGENOTEXISTS },
{ NC_("RID_SVXERRCODE", "Spellcheck is not available.") ,
ERRCODE_SVX_LINGU_LINGUNOTEXISTS },
diff --git a/sw/source/core/access/AccessibilityIssue.cxx b/sw/source/core/access/AccessibilityIssue.cxx
index 075fa15ceb51..fe7d409091ca 100644
--- a/sw/source/core/access/AccessibilityIssue.cxx
+++ b/sw/source/core/access/AccessibilityIssue.cxx
@@ -360,7 +360,7 @@ void AccessibilityIssue::quickFixIssue() const
if (m_sObjectID.isEmpty())
{
- // open the dialog "Tools/Options/Language Settings - Language"
+ // open the dialog "Tools/Options/Languages and Locales - General"
uno::Sequence<beans::PropertyValue> aArgs{ comphelper::makePropertyValue(
"Language", OUString("*")) };
diff --git a/sw/source/filter/ww8/wrtw8sty.cxx b/sw/source/filter/ww8/wrtw8sty.cxx
index cf62d9ded167..73ce9bc8434f 100644
--- a/sw/source/filter/ww8/wrtw8sty.cxx
+++ b/sw/source/filter/ww8/wrtw8sty.cxx
@@ -387,7 +387,7 @@ void MSWordStyles::BuildWwNames()
// We want to map LO's default style to Word's "Normal" style.
// Word looks for this specific style name when reading docx files.
- // (It must be the English word regardless of language settings)
+ // (It must be the English word regardless of languages and locales)
assert(!m_aStyles.empty());
assert(!m_aStyles[0].format || m_aStyles[0].ww_id == ww::stiNormal);
m_aStyles[0].ww_name = "Normal";
diff --git a/sw/source/uibase/shells/langhelper.cxx b/sw/source/uibase/shells/langhelper.cxx
index 446cd55e4c34..453e0c1d93aa 100644
--- a/sw/source/uibase/shells/langhelper.cxx
+++ b/sw/source/uibase/shells/langhelper.cxx
@@ -111,7 +111,7 @@ namespace SwLangHelper
if (aNewLangText == "*" )
{
- // open the dialog "Tools/Options/Language Settings - Language"
+ // open the dialog "Tools/Options/Languages and Locales - General"
SfxAbstractDialogFactory* pFact = SfxAbstractDialogFactory::Create();
ScopedVclPtr<VclAbstractDialog> pDlg(pFact->CreateVclDialog( rView.GetFrameWeld(), SID_LANGUAGE_OPTIONS ));
pDlg->Execute();
diff --git a/sw/source/uibase/shells/textsh1.cxx b/sw/source/uibase/shells/textsh1.cxx
index 746e47dd8668..2bf6c670e489 100644
--- a/sw/source/uibase/shells/textsh1.cxx
+++ b/sw/source/uibase/shells/textsh1.cxx
@@ -847,7 +847,7 @@ void SwTextShell::Execute(SfxRequest &rReq)
if (aNewLangText == "*")
{
- // open the dialog "Tools/Options/Language Settings - Language"
+ // open the dialog "Tools/Options/Languages and Locales - General"
// to set the documents default language
SfxAbstractDialogFactory* pFact = SfxAbstractDialogFactory::Create();
ScopedVclPtr<VclAbstractDialog> pDlg(pFact->CreateVclDialog(GetView().GetFrameWeld(), SID_LANGUAGE_OPTIONS));
diff --git a/sw/uiconfig/swriter/ui/textgridpage.ui b/sw/uiconfig/swriter/ui/textgridpage.ui
index a7438fe6d055..ecbb85edaeba 100644
--- a/sw/uiconfig/swriter/ui/textgridpage.ui
+++ b/sw/uiconfig/swriter/ui/textgridpage.ui
@@ -577,7 +577,7 @@
</child>
<child internal-child="accessible">
<object class="AtkObject" id="TextGridPage-atkobject">
- <property name="AtkObject::accessible-description" translatable="yes" context="textgridpage|extended_tip|TextGridPage">Adds a text grid to the current page style. This option is only available if Asian language support is enabled under Language Settings - Languages in the Options dialog box.</property>
+ <property name="AtkObject::accessible-description" translatable="yes" context="textgridpage|extended_tip|TextGridPage">Adds a text grid to the current page style. This option is only available if Asian language support is enabled under Languages and Locales - General in the Options dialog box.</property>
</object>
</child>
</object>
diff --git a/sw/qa/uitest/findReplace/tdf118208.py b/sw/qa/uitest/findReplace/tdf118208.py
index eab70452510c..3735c6cdab53 100644
--- a/sw/qa/uitest/findReplace/tdf118208.py
+++ b/sw/qa/uitest/findReplace/tdf118208.py
@@ -9,9 +9,10 @@
from uitest.framework import UITestCase
from uitest.uihelper.common import get_state_as_dict, get_url_for_data_file
-#Find and replace
-#tdf118208/118212 - enabling either CJK or CTL, or both (Tools -> Options -> Language Settings -> Languages: Default Languages for Documents checkboxes)
-#eliminates all crashes. Setting back to Western only recreates the crashes. - DONE
+# Find and replace
+# tdf118208/118212 - enabling either CJK or CTL, or both (Tools -> Options -> Languages and Locales -> General: Default Languages for Documents checkboxes)
+# eliminates all crashes. Setting back to Western only recreates the crashes. - DONE
+
class tdf118208(UITestCase):
@@ -19,10 +20,10 @@ class tdf118208(UITestCase):
with self.ui_test.execute_dialog_through_command(".uno:OptionsTreeDialog") as xDialog:
xPages = xDialog.getChild("pages")
- xLanguageEntry = xPages.getChild('2') # Language Settings
+ xLanguageEntry = xPages.getChild('2') # Languages and Locales
xLanguageEntry.executeAction("EXPAND", tuple())
xxLanguageEntryGeneralEntry = xLanguageEntry.getChild('0')
- xxLanguageEntryGeneralEntry.executeAction("SELECT", tuple()) #Language
+ xxLanguageEntryGeneralEntry.executeAction("SELECT", tuple()) # General
asianlanguage = xDialog.getChild("asiansupport")
complexlanguage = xDialog.getChild("ctlsupport")
@@ -36,7 +37,7 @@ class tdf118208(UITestCase):
# 1. Open the attached file.
# 2. Press ctrl-H to show the search and replace dialog.
# 3. Press the "Format..." button.
- #Libreoffice immediately crashed.
+ # Libreoffice immediately crashed.
try:
self.change_default_languages("false")